import React from 'react';
import { View, Text, StyleSheet, ScrollView, TouchableOpacity, Image, TextInput, Modal } from 'react-native';
import { connect } from 'react-redux';
import ActionType from '../redux/globalActionType';
import NumberFormat from 'react-number-format';
import { Icon } from 'react-native-elements'


class ItemShoping extends React.Component {
    constructor(props) {
        super(props)
        this.state = {
            value: 0,
            modalVisible: false,
            description: ''
        }
    }
    handleChangeQuantity = (item, quantity) => {

        console.log('CHange Quantity Shopping CHart : ' + JSON.stringify(item))
        console.log('new quantity : ' + quantity)
        if (quantity == '') {
            item.quantity = 1
        }
        this.props.onChange()
        const order_item = {
            id: item.id,
            code: item.code,
            name: item.name,
            description: item.description,
            note: item.note,
            image: item.image,
            price: parseInt(item.price),
        }
        this.props.changeQuantity({ item: order_item, quantity: quantity })
    }

    handleAddDescription() {
        this.setState({
            modalVisible: true
        })
    }

    render() {
        const { item } = this.props
        // console.log(this.props)
        return (

            <View style={{ flex: 1 }} key={item.id}>
                {/* <Text style={{ fontSize: 20, color: '#c9af6d' }}>{item.name}</Text> */}
                <Modal animationType="slide"
                    transparent={true}
                    visible={this.state.modalVisible}
                    onRequestClose={() => {
                        this.setState({
                            modalVisible: false
                        })
                    }}>
                    <View style={styles.centerViewModal}>
                        <View style={styles.modalView}>
                            <Text style={{ fontSize: 12, color: '#CFB368', fontFamily: 'Gotham-Black' }}>Add Description</Text>
                            <View style={{ margin: 10 }}>
                                <TextInput
                                    style={styles.textInput}
                                    onChangeText={(description) => this.setState({ description })}
                                    value={this.state.description}
                                    textAlign='center'
                                />
                            </View>
                            <TouchableOpacity onPress={() => this.setState({ modalVisible: false })}>
                                <View style={styles.button}>
                                    <Text style={{ color: 'white', fontWeight: 'bold', fontSize: 16 }}>CONFIRM</Text>
                                </View>
                            </TouchableOpacity>
                        </View>
                    </View>

                </Modal>
                <View style={{ flex: 1, flexDirection: 'row', height: 100, marginVertical:5 }}>
                    <View style={{ flex: 1, height: 100 }}>
                        <TouchableOpacity onPress={() => this.props.navigation.navigate('Menu Detail', { nameMenu: item.name, desc: item.description, image: item.image })}>
                            <Image source={{ uri: item.image }} style={{ height: 100, width: 100, borderRadius: 10, }}></Image>
                        </TouchableOpacity>
                    </View>
                    <View style={{ flex: 2, height: 150 }}>
                        <View style={{ marginLeft: 5, marginRight: 5 }}>
                            <Text style={{ fontSize: 14, margin: 5, marginRight: 10, fontFamily: 'Gotham-Black', color: '#838383' }}>{item.name}</Text>
                            <NumberFormat decimalScale={0} value={item.price} renderText={value => <Text style={{ fontSize: 14, margin: 5, marginRight: 10, fontFamily: 'Gotham-Light', color: 'grey' }}>Rp. {value}</Text>} displayType={'text'} thousandSeparator={true} prefix={''} />
                        </View>
                        <View style={{ marginLeft: 5, marginRight: 5, flexDirection: 'row' }}>
                            <TouchableOpacity style={{ justifyContent: 'center' }} onPress={() => this.handleAddDescription()}>
                                <View style={styles.shadowEdit}>
                                    <Icon
                                        name='pencil'
                                        type='simple-line-icon'
                                        color='#838383'
                                        size={18}
                                    />
                                </View>
                            </TouchableOpacity>
                            <View style={styles.shadowAdd}>
                                <TouchableOpacity style={{ alignSelf: 'center' }} onPress={() => this.props.handleMin()}>
                                    <Icon
                                        name='minus'
                                        type='font-awesome'
                                        color='#CFB368'
                                        size={18}
                                    />
                                </TouchableOpacity>
                                <TextInput
                                    style={{ padding: 2, textAlign: 'center', fontFamily: 'Gotham-Black', color: '#838383', fontSize: 14, marginRight: 5, marginLeft: 5 }}
                                    keyboardType={'numeric'}
                                    onChangeText={(quantity) => this.handleChangeQuantity(item, quantity)}>{item.quantity}</TextInput>
                                <TouchableOpacity style={{ alignSelf: 'center' }} onPress={() => this.props.handleAdd()}>
                                    <Icon
                                        name='plus'
                                        type='font-awesome'
                                        color='#CFB368'
                                        size={18}
                                    />
                                </TouchableOpacity>
                            </View>
                        </View>
                    </View>
                </View>
            </View>
        )
    }
}

const styles = StyleSheet.create({
    shadowEdit: {
        height: 30,
        width: 40,
        borderWidth: 1,
        borderRadius: 2,
        borderColor: '#ddd',
        borderBottomWidth: 0,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.8,
        shadowRadius: 2,
        elevation: 0.5,
        marginLeft: 5,
        marginRight: 5,
        marginTop: 5,
        justifyContent: 'center'
    },
    shadowAdd: {
        height: 30,
        width: 90,
        borderWidth: 1,
        borderRadius: 2,
        borderColor: '#ddd',
        borderBottomWidth: 0,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.8,
        shadowRadius: 2,
        elevation: 1,
        marginLeft: 5,
        marginRight: 5,
        marginTop: 5,
        flexDirection: 'row',
        justifyContent: 'center'
    },
    shadowMin: {
        height: 20,
        width: 20,
        borderWidth: 1,
        borderRadius: 2,
        borderColor: '#ddd',
        borderBottomWidth: 0,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.8,
        shadowRadius: 2,
        elevation: 1,
        marginLeft: 5,
        marginRight: 5,
        marginTop: 10,
    },
    centerViewModal: {
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    modalView: {
        backgroundColor: "white",
        borderRadius: 10,
        borderWidth: 1,
        borderColor: 'grey',
        padding: 20,
        alignItems: "center",
    },
    textInput: {
        height: 40,
        width: 250,
        fontFamily: 'Gotham-Light',
        fontSize: 14,
        color: '#838383',
        borderColor: 'gray',
        borderWidth: 1,
        marginHorizontal: 30,
        borderRadius: 10
    },
    button: {
        backgroundColor: '#CFB368',
        height: 40,
        paddingHorizontal:20,
        borderRadius: 10,
        alignItems: 'center',
        justifyContent: 'center'
    },
})

const mapStateToProps = (state) => {
    // console.log(state)
    return {
        session_id: state.session_id,
        outlet_id: state.outlet_id,
        order_quantity: state.order_quantity,
        order_total: state.order_total,
        quantity: state.quantity,
    }
}

const mapDispatchToProps = (dispacth) => {
    return {
        changeQuantity: (params) => dispacth({
            type: ActionType.CHANGE_QUANTITY,
            data: {
                item: params.item,
                new_quantity: params.quantity
            }
        }),
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(ItemShoping)
